==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/DisplaystringCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Displaystring;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DisplaystringRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class DisplaystringCollectionRequest extends CollectionPageEntityRequest<Displaystring, DisplaystringRequest>{

    protected ContextPath contextPath;

    public DisplaystringCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Displaystring.class, cp -> new DisplaystringRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public AsyncoperationCollectionRequest displayString_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("DisplayString_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest displayString_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("DisplayString_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest displayString_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("DisplayString_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest displayString_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("DisplayString_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/DisplaystringCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Displaystring;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DisplaystringRequest;

public class DisplaystringCollectionRequest extends CollectionPageEntityRequest<Displaystring, DisplaystringRequest>{

    protected ContextPath contextPath;

    public DisplaystringCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Displaystring.class, cp -> new DisplaystringRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public AsyncoperationCollectionRequest displayString_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("DisplayString_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest displayString_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("DisplayString_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest displayString_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("DisplayString_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest displayString_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("DisplayString_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

}
